/**
 * @file libgalago-gtk/galago-gtk-account-option-menu.h
 *       Account OptionMenu widget.
 *
 * @Copyright (C) 2004-2005 Christian Hammond.
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
#ifndef _GALAGO_GTK_ACCOUNT_OPTION_MENU_H_
#define _GALAGO_GTK_ACCOUNT_OPTION_MENU_H_

#include <gtk/gtk.h>

typedef struct _GalagoGtkAccountOptionMenu      GalagoGtkAccountOptionMenu;
typedef struct _GalagoGtkAccountOptionMenuClass GalagoGtkAccountOptionMenuClass;
typedef struct _GalagoGtkAccountOptionMenuPriv  GalagoGtkAccountOptionMenuPriv;

#include <libgalago/galago.h>

#include <libgalago-gtk/galago-gtk-service-option-menu.h>

#define GALAGO_GTK_TYPE_ACCOUNT_OPTION_MENU (galago_gtk_account_option_menu_get_type())
#define GALAGO_GTK_ACCOUNT_OPTION_MENU(obj) \
		(G_TYPE_CHECK_INSTANCE_CAST((obj), GALAGO_GTK_TYPE_ACCOUNT_OPTION_MENU, GalagoGtkAccountOptionMenu))
#define GALAGO_GTK_ACCOUNT_OPTION_MENU_CLASS(klass) \
		(G_TYPE_CHECK_CLASS_CAST((klass), GALAGO_GTK_TYPE_ACCOUNT_OPTION_MENU, GalagoGtkAccountOptionMenuClass))
#define GALAGO_GTK_IS_ACCOUNT_OPTION_MENU(obj) \
		(G_TYPE_CHECK_INSTANCE_TYPE((obj), GALAGO_GTK_TYPE_ACCOUNT_OPTION_MENU))
#define GALAGO_GTK_IS_ACCOUNT_OPTION_MENU_CLASS(klass) \
		(G_TYPE_CHECK_CLASS_TYPE((klass), GALAGO_GTK_TYPE_ACCOUNT_OPTION_MENU))
#define GALAGO_GTK_ACCOUNT_OPTION_MENU_GET_CLASS(obj) \
		(G_TYPE_INSTANCE_GET_CLASS ((obj), GALAGO_GTK_TYPE_ACCOUNT_OPTION_MENU, GalagoGtkAccountOptionMenuClass))

struct _GalagoGtkAccountOptionMenu
{
	GtkOptionMenu parent_object;

	GalagoGtkAccountOptionMenuPriv *priv;

	void (*gtk_reserved1)(void);
	void (*gtk_reserved2)(void);
	void (*gtk_reserved3)(void);
	void (*gtk_reserved4)(void);
};

struct _GalagoGtkAccountOptionMenuClass
{
	GtkOptionMenuClass parent_class;

	/* Signals */
	void (*account_changed)(GalagoGtkAccountOptionMenu *optmenu,
							GalagoAccount *account);

	void (*gtk_reserved1)(void);
	void (*gtk_reserved2)(void);
	void (*gtk_reserved3)(void);
	void (*gtk_reserved4)(void);
};

G_BEGIN_DECLS

GType galago_gtk_account_option_menu_get_type(void);

GtkWidget *galago_gtk_account_option_menu_new(gboolean me_accounts);

void galago_gtk_account_option_menu_set_person(
	GalagoGtkAccountOptionMenu *optmenu, GalagoPerson *person);
GalagoPerson *galago_gtk_account_option_menu_get_person(
	const GalagoGtkAccountOptionMenu *optmenu);
void galago_gtk_account_option_menu_set_service(
	GalagoGtkAccountOptionMenu *optmenu, GalagoService *service);
GalagoService *galago_gtk_account_option_menu_get_service(
	const GalagoGtkAccountOptionMenu *optmenu);

void galago_gtk_account_option_menu_set_active(
	GalagoGtkAccountOptionMenu *optmenu, const GalagoAccount *account);
GalagoAccount *galago_gtk_account_option_menu_get_active(
	const GalagoGtkAccountOptionMenu *optmenu);

void galago_gtk_account_option_menu_set_services_option_menu(
	GalagoGtkAccountOptionMenu *optmenu, GtkWidget *service_optmenu);
GtkWidget *galago_gtk_account_option_menu_get_services_option_menu(
	const GalagoGtkAccountOptionMenu *optmenu);

G_END_DECLS

#endif /* _GALAGO_GTK_ACCOUNT_OPTION_MENU_H_ */
