/* GTK - The GIMP Toolkit
 * Copyright (C) 1995-1997 Peter Mattis, Spencer Kimball and Josh MacDonald
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.	 See the GNU
 * Lesser General Public License for more details.
 *
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA 02111-1307, USA.
 */

/*
 * Modified by the GTK+ Team and others 1997-2000.  See the AUTHORS
 * file for a list of people on the GTK+ Team.  See the ChangeLog
 * files for a list of changes.  These files are distributed with
 * GTK+ at ftp://ftp.gtk.org/pub/gtk/.
 */

/*
 * This modification of GtkTooltips by the GEdit people is being modified
 * for use in the Galago project.
 */

#ifndef _GALAGO_GTK_TOOLTIPS_H_
#define _GALAGO_GTK_TOOLTIPS_H_

#include <gtk/gtkwidget.h>

G_BEGIN_DECLS

#define GALAGO_GTK_TYPE_TOOLTIPS                  (galago_gtk_tooltips_get_type ())
#define GALAGO_GTK_TOOLTIPS(obj)                  (G_TYPE_CHECK_INSTANCE_CAST ((obj), GALAGO_GTK_TYPE_TOOLTIPS, GalagoGtkTooltips))
#define GALAGO_GTK_TOOLTIPS_CLASS(klass)          (G_TYPE_CHECK_CLASS_CAST ((klass), GALAGO_GTK_TYPE_TOOLTIPS, GalagoGtkTooltipsClass))
#define GALAGO_GTK_IS_TOOLTIPS(obj)               (G_TYPE_CHECK_INSTANCE_TYPE ((obj), GALAGO_GTK_TYPE_TOOLTIPS))
#define GALAGO_GTK_IS_TOOLTIPS_CLASS(klass)       (G_TYPE_CHECK_CLASS_TYPE ((klass), GALAGO_GTK_TYPE_TOOLTIPS))
#define GALAGO_GTK_TOOLTIPS_GET_CLASS(obj)        (G_TYPE_INSTANCE_GET_CLASS ((obj), GALAGO_GTK_TYPE_TOOLTIPS, GalagoGtkTooltipsClass))


typedef struct _GalagoGtkTooltips      GalagoGtkTooltips;
typedef struct _GalagoGtkTooltipsClass GalagoGtkTooltipsClass;
typedef struct _GalagoGtkTooltipsData  GalagoGtkTooltipsData;

typedef char *(*GalagoGtkTooltipFunc)(const GtkWidget *widget);

struct _GalagoGtkTooltipsData
{
	GalagoGtkTooltips *tooltips;
	GtkWidget *widget;
	gchar *tip_text;
	gchar *tip_private;

	GalagoGtkTooltipFunc tip_func;
	GtkWidget *tip_func_widget;
};

struct _GalagoGtkTooltips
{
	GtkObject parent_instance;

	GtkWidget *tip_window;
	GtkWidget *tip_label;
	GalagoGtkTooltipsData *active_tips_data;
	GList *tips_data_list;

	guint delay : 30;
	guint enabled : 1;
	guint have_grab : 1;
	guint use_sticky_delay : 1;
	gint timer_tag;
	GTimeVal last_popdown;
};

struct _GalagoGtkTooltipsClass
{
	GtkObjectClass parent_class;

	/* Padding for future expansion */
	void (*_gtk_reserved1)(void);
	void (*_gtk_reserved2)(void);
	void (*_gtk_reserved3)(void);
	void (*_gtk_reserved4)(void);
};

GType galago_gtk_tooltips_get_type(void) G_GNUC_CONST;
GalagoGtkTooltips *galago_gtk_tooltips_new(void);

void galago_gtk_tooltips_enable(GalagoGtkTooltips *tooltips);
void galago_gtk_tooltips_disable(GalagoGtkTooltips *tooltips);

void galago_gtk_tooltips_set_tip(GalagoGtkTooltips *tooltips,
								 GtkWidget *widget,
								 const gchar *tip_text,
								 const gchar *tip_private);
void galago_gtk_tooltips_set_tip_func(GalagoGtkTooltips *tooltips,
									  GtkWidget *widget,
									  GalagoGtkTooltipFunc func,
									  GtkWidget *func_widget);

GalagoGtkTooltipsData *galago_gtk_tooltips_data_get(GtkWidget *widget);
void galago_gtk_tooltips_force_window(GalagoGtkTooltips *tooltips);

void _galago_gtk_tooltips_toggle_keyboard_mode(GtkWidget *widget);

G_END_DECLS

#endif /* __GALAGO_GTK_TOOLTIPS_H__ */
